Package: ecolitk
Version: 1.84.0
Date: 2010-04
Title: Meta-data and tools for E. coli
Author: Laurent Gautier
Maintainer: Laurent Gautier <lgautier@gmail.com>
biocViews: Annotation, Visualization
Depends: R (>= 2.10)
Imports: Biobase, graphics, methods
Suggests: ecoliLeucine, ecolicdf, graph, multtest, affy
Description: Meta-data and tools to work with E. coli. The tools are
        mostly plotting functions to work with circular genomes. They
        can used with other genomes/plasmids.
License: GPL (>= 2)
git_url: https://git.bioconductor.org/packages/ecolitk
git_branch: RELEASE_3_23
git_last_commit: aef6a78
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:53:02 UTC; biocbuild
